Crate async_rt_macros

Crate async_rt_macros 

Attribute macros for async-rt.

Attribute Macros

main_compio
Runs an async function as a synchronous entry point.
main_fail
Runs an async function when no default runtime is enabled.
main_lite
Runs an async function as a synchronous entry point.
main_smol
Runs an async function as a synchronous entry point.
main_threadpool
Runs an async function as a synchronous entry point.
main_tokio
Runs an async function as a synchronous entry point.
main_wasm_fail
Emits an error because no supported runtime is available.
test_compio
Runs an async function as a synchronous test.
test_fail
Runs an async test when no default runtime is enabled.
test_lite
Runs an async function as a synchronous test.
test_smol
Runs an async function as a synchronous test.
test_threadpool
Runs an async function as a synchronous test.
test_tokio
Runs an async function as a synchronous test.
test_wasm_fail
Emits an error because no supported test runtime is available.