Attribute macros for async-rt.
Attribute Macros
- main_
compio - Runs an async function as a synchronous entry point.
- main_
fail - Runs an async function when no default runtime is enabled.
- main_
lite - Runs an async function as a synchronous entry point.
- main_
smol - Runs an async function as a synchronous entry point.
- main_
threadpool - Runs an async function as a synchronous entry point.
- main_
tokio - Runs an async function as a synchronous entry point.
- main_
wasm_ fail - Emits an error because no supported runtime is available.
- test_
compio - Runs an async function as a synchronous test.
- test_
fail - Runs an async test when no default runtime is enabled.
- test_
lite - Runs an async function as a synchronous test.
- test_
smol - Runs an async function as a synchronous test.
- test_
threadpool - Runs an async function as a synchronous test.
- test_
tokio - Runs an async function as a synchronous test.
- test_
wasm_ fail - Emits an error because no supported test runtime is available.